@@ -77,22 +77,6 @@ class GetDatasetTests:
         assert response.get("size") == "177M" or response.get("size") == "176M"
 
 
-@mark.create
-@mark.asyncio
-async def test_dataset_aws(trainml, capsys):
-    dataset = await trainml.datasets.create(
-        name="CLI Automated AWS",
-        source_type="aws",
-        source_uri="s3://trainml-examples/data/cifar10",
-    )
-    dataset = await dataset.wait_for("ready", 300)
-    status = dataset.status
-    size = dataset.size
-    await dataset.remove()
-    assert status == "ready"
-    assert size >= 10000000
-
-
 @mark.create
 @mark.asyncio
 async def test_dataset_local(trainml, capsys):
@@ -116,4 +100,4 @@ async def test_dataset_local(trainml, capsys):
     sys.stderr.write(captured.err)
     assert "Starting data upload from local" in captured.out
     assert "data_batch_1.bin  30733788 bytes" in captured.out
-    assert "Upload complete" in captured.out
\ No newline at end of file
+    assert "Upload complete" in captured.out
