@@ -18,7 +18,7 @@ async def job(trainml):
         gpu_types=["gtx1060"],
         gpu_count=1,
         disk_size=11,
-        data=dict(datasets=[dict(name="CIFAR-10", type="public")]),
+        data=dict(datasets=[dict(id="CIFAR-10", public=True)]),
         model=dict(
             source_type="git",
             source_uri="git@github.com:trainML/environment-tests.git",
@@ -32,7 +32,7 @@ async def job(trainml):
 class JobLifeCycleTests:
     async def test_wait_for_running(self, job):
         assert job.status != "running"
-        job = await job.wait_for("running", 180)
+        job = await job.wait_for("running")
         assert job.status == "running"
 
     async def test_stop_job(self, job):
@@ -85,6 +85,7 @@ class JobLifeCycleTests:
         )
 
     async def test_copy_job(self, job):
+        await job.wait_for("running", 300)
         job_copy = await job.copy("CLI Automated Tests - Job Copy")
         assert job_copy.id != job.id
         await job_copy.wait_for("running", 300)
@@ -95,6 +96,7 @@ class JobLifeCycleTests:
         await job_copy.remove()
 
     async def test_convert_job(self, job):
+        await job.wait_for("running", 300)
         training_job = await job.copy(
             name="CLI Automated Tests - Job Convert",
             type="training",
@@ -102,8 +104,8 @@ class JobLifeCycleTests:
             data=dict(
                 datasets=[
                     dict(
-                        name="CIFAR-10",
-                        type="public",
+                        id="CIFAR-10",
+                        public=True,
                     )
                 ],
                 output_uri="s3://trainml-examples/output/resnet_cifar10",
@@ -113,6 +115,8 @@ class JobLifeCycleTests:
         assert training_job.id
         training_job = await training_job.wait_for("finished", 300)
         assert training_job.status == "finished"
+        await asyncio.sleep(10)  ## give billing a chance to update
+        await training_job.refresh()
         assert training_job.credits > 0
         assert training_job.credits < 0.1
         await training_job.remove()
@@ -306,7 +310,7 @@ class JobAPIDataValidationTests:
                 type="inference",
                 gpu_types=["rtx3090"],
                 disk_size=10,
-                data=dict(datasets=[dict(id="CIFAR-10", type="public")]),
+                data=dict(datasets=[dict(id="CIFAR-10", public=True)]),
                 workers=["python predict.py"],
             )
         assert (
@@ -370,12 +374,20 @@ class JobIOTests:
             gpu_types=["gtx1060"],
             disk_size=10,
             workers=["python $TRAINML_MODEL_PATH/tensorflow/main.py"],
-            environment=dict(type="TENSORFLOW_PY39_29"),
+            environment=dict(
+                type="DEEPLEARNING_PY39",
+                env=[
+                    dict(
+                        key="CHECKPOINT_FILE",
+                        value="model.ckpt-0050",
+                    )
+                ],
+            ),
             data=dict(
                 datasets=[
                     dict(
-                        name="CIFAR-10",
-                        type="public",
+                        id="CIFAR-10",
+                        public=True,
                     )
                 ],
                 output_uri=temp_dir.name,
@@ -384,9 +396,12 @@ class JobIOTests:
             model=dict(
                 source_type="git",
                 source_uri="git@github.com:trainML/environment-tests.git",
+                checkpoints=[
+                    "tensorflow-checkpoint",
+                ],
             ),
         )
-        await job.wait_for("running")
+        await job.wait_for("waiting for data/model download")
         attach_task = asyncio.create_task(job.attach())
         connect_task = asyncio.create_task(job.connect())
         await asyncio.gather(attach_task, connect_task)
@@ -395,12 +410,11 @@ class JobIOTests:
         await job.disconnect()
         await job.remove()
         upload_contents = os.listdir(temp_dir.name)
-        result = any(
-            "CLI_Automated_Tensorflow_Test_1" in content
+        temp_dir.cleanup()
+        assert any(
+            "CLI_Automated_Tests_-_Local_Output" in content
             for content in upload_contents
         )
-        assert result is not None
-        temp_dir.cleanup()
 
         captured = capsys.readouterr()
         sys.stdout.write(captured.out)
@@ -428,12 +442,11 @@ class JobIOTests:
             cpu_count=8,
             disk_size=10,
             worker_commands=["python $TRAINML_MODEL_PATH/tensorflow/main.py"],
-            environment=dict(type="TENSORFLOW_PY39_29"),
             data=dict(
                 datasets=[
                     dict(
-                        name="CIFAR-10",
-                        type="public",
+                        id="CIFAR-10",
+                        public=True,
                     )
                 ],
                 output_type="trainml",
@@ -537,7 +550,7 @@ class JobTypeTests:
             ),
             environment=dict(
                 type="CUSTOM",
-                custom_image="tensorflow/tensorflow:2.5.1-gpu",
+                custom_image="tensorflow/tensorflow:2.10.0-gpu",
                 packages=dict(
                     pip=[
                         "tensorflow_addons",
@@ -555,8 +568,8 @@ class JobTypeTests:
             data=dict(
                 datasets=[
                     dict(
-                        name="CIFAR-10",
-                        type="public",
+                        id="CIFAR-10",
+                        public=True,
                     )
                 ],
                 output_type="wasabi",
@@ -607,8 +620,8 @@ class JobFeatureTests:
             data=dict(
                 datasets=[
                     dict(
-                        name="CIFAR-10",
-                        type="public",
+                        id="CIFAR-10",
+                        public=True,
                     )
                 ],
             ),
@@ -658,13 +671,12 @@ class JobFeatureTests:
         sys.stdout.write(captured.out)
         sys.stderr.write(captured.err)
         upload_contents = os.listdir(temp_dir.name)
+        temp_dir.cleanup()
         assert len(upload_contents) > 4
-        result = any(
+        assert any(
             "model.ckpt-0002.data-00000-of-00001" in content
             for content in upload_contents
         )
-        assert result is not None
-        temp_dir.cleanup()
 
         captured = capsys.readouterr()
         sys.stdout.write(captured.out)
@@ -672,4 +684,4 @@ class JobFeatureTests:
         assert "Epoch 1/2" in captured.out
         assert "Epoch 2/2" in captured.out
         assert "Number of regular files transferred: 7" in captured.out
-        assert "Send complete" in captured.out
\ No newline at end of file
+        assert "Send complete" in captured.out
