@@ -163,7 +163,9 @@ def configure(config):
 from trainml.cli.connection import connection
 from trainml.cli.dataset import dataset
 from trainml.cli.model import model
+from trainml.cli.checkpoint import checkpoint
 from trainml.cli.environment import environment
 from trainml.cli.gpu import gpu
 from trainml.cli.job import job
-from trainml.cli.project import project
\ No newline at end of file
+from trainml.cli.project import project
+from trainml.cli.provider import provider
