@@ -56,6 +56,7 @@ def create(config):
             "v100",
             "a100",
             "a6000",
+            "a4000",
             "cpu",
         ],
         case_sensitive=False,
@@ -90,18 +91,31 @@ def create(config):
     help="ID or Name of a public dataset to add to the job",
     multiple=True,
 )
+@click.option(
+    "--checkpoint",
+    type=click.STRING,
+    help="ID or Name of a checkpoint to add to the job",
+    multiple=True,
+)
+@click.option(
+    "--public-checkpoint",
+    type=click.STRING,
+    help="ID or Name of a public checkpoint to add to the job",
+    multiple=True,
+)
 @click.option(
     "--environment",
     type=click.Choice(
         [
             "DEEPLEARNING_PY38",
             "DEEPLEARNING_PY39",
+            "PYTORCH_PY39_113",
             "PYTORCH_PY39_112",
             "PYTORCH_PY38_110",
             "PYTORCH_PY38_19",
             "PYTORCH_PY38_18",
-            "TENSORFLOW_PY39_29",
-            "TENSORFLOW_PY39_28",
+            "TENSORFLOW_PY39_211",
+            "TENSORFLOW_PY39_210",
             "TENSORFLOW_PY38_26",
             "MXNET_PY39_19",
             "MXNET_PY38_18",
@@ -116,7 +130,6 @@ def create(config):
     "--custom-image",
     type=click.STRING,
     help="Docker Image to use for the job.  Implies 'CUSTOM' environment type.",
-    multiple=True,
 )
 @click.option(
     "--env",
@@ -142,11 +155,7 @@ def create(config):
 @click.option(
     "--key",
     type=click.Choice(
-        [
-            "aws",
-            "gcp",
-            "kaggle",
-        ],
+        ["aws", "gcp", "kaggle", "azure", "wasabi"],
         case_sensitive=False,
     ),
     help="Third Party Keys to add to the job environment",
@@ -167,6 +176,13 @@ def create(config):
     type=click.Path(exists=True, file_okay=False, resolve_path=True),
     help="Local file path to copy as the model data",
 )
+@click.option(
+    "--timeout",
+    type=click.INT,
+    default=300,
+    show_default=True,
+    help="Seconds to wait for job to start",
+)
 @click.argument("name", type=click.STRING)
 @pass_config
 def notebook(
@@ -180,6 +196,8 @@ def notebook(
     data_dir,
     dataset,
     public_dataset,
+    checkpoint,
+    public_checkpoint,
     environment,
     custom_image,
     env,
@@ -190,25 +208,40 @@ def notebook(
     model_dir,
     git_uri,
     model_id,
+    timeout,
     name,
 ):
     """
     Create a notebook.
     """
 
-    datasets = [dict(id=item, type="existing") for item in dataset] + [
-        dict(id=item, type="public") for item in public_dataset
-    ]
+    datasets = [
+        dict(
+            id=item,
+        )
+        for item in dataset
+    ] + [dict(id=item, public=True) for item in public_dataset]
+
+    checkpoints = [
+        dict(
+            id=item,
+        )
+        for item in checkpoint
+    ] + [dict(id=item, public=True) for item in public_checkpoint]
 
     options = dict(
         max_price=max_price,
         data=dict(datasets=datasets),
+        model=dict(checkpoints=checkpoints),
         environment=dict(
-            type="CUSTOM" if custom_image else environment,
-            custom_image=custom_image,
             worker_key_types=[k for k in key],
         ),
     )
+    if custom_image:
+        options["environment"]["type"] = "CUSTOM"
+        options["environment"]["custom_image"] = custom_image
+    else:
+        options["environment"]["type"] = environment
 
     try:
         envs = [
@@ -250,11 +283,15 @@ def notebook(
         )
 
     if git_uri:
-        options["model"] = dict(source_type="git", source_uri=git_uri)
+        options["model"]["source_type"] = "git"
+        options["model"]["source_uri"] = git_uri
     if model_id:
-        options["model"] = dict(source_type="trainml", source_uri=model_id)
+        options["model"]["source_type"] = "trainml"
+        options["model"]["source_uri"] = model_id
     if model_dir:
-        options["model"] = dict(source_type="local", source_uri=model_dir)
+        options["model"]["source_type"] = "local"
+        options["model"]["source_uri"] = model_dir
+
     job = config.trainml.run(
         config.trainml.client.jobs.create(
             name=name,
@@ -280,9 +317,9 @@ def notebook(
             config.trainml.run(job.disconnect())
     elif attach or connect:
         click.echo("Waiting for job to start...", file=config.stdout)
-        config.trainml.run(job.wait_for("running"))
+        config.trainml.run(job.wait_for("running", timeout))
         click.echo("Launching...", file=config.stdout)
-        browse(job.notebook_url)
+        config.trainml.run(job.open())
 
 
 @create.command()
@@ -329,6 +366,7 @@ def notebook(
             "v100",
             "a100",
             "a6000",
+            "a4000",
             "cpu",
         ],
         case_sensitive=False,
@@ -362,6 +400,18 @@ def notebook(
     help="ID or Name of a public dataset to add to the job",
     multiple=True,
 )
+@click.option(
+    "--checkpoint",
+    type=click.STRING,
+    help="ID or Name of a checkpoint to add to the job",
+    multiple=True,
+)
+@click.option(
+    "--public-checkpoint",
+    type=click.STRING,
+    help="ID or Name of a public checkpoint to add to the job",
+    multiple=True,
+)
 @click.option(
     "--output-dir",
     type=click.Path(exists=True, file_okay=False, resolve_path=True),
@@ -370,7 +420,7 @@ def notebook(
 @click.option(
     "--output-type",
     type=click.Choice(
-        ["aws", "gcp", "local", "trainml"],
+        ["aws", "gcp", "local", "trainml", "azure", "wasabi"],
         case_sensitive=False,
     ),
     help="Service provider to store the output data",
@@ -380,18 +430,25 @@ def notebook(
     type=click.STRING,
     help="Location in the output-type provider to store the output data",
 )
+@click.option(
+    "--archive/--no-archive",
+    default=False,
+    show_default=True,
+    help="Zip the output contents before uploading.",
+)
 @click.option(
     "--environment",
     type=click.Choice(
         [
             "DEEPLEARNING_PY38",
             "DEEPLEARNING_PY39",
+            "PYTORCH_PY39_113",
             "PYTORCH_PY39_112",
             "PYTORCH_PY38_110",
             "PYTORCH_PY38_19",
             "PYTORCH_PY38_18",
-            "TENSORFLOW_PY39_29",
-            "TENSORFLOW_PY39_28",
+            "TENSORFLOW_PY39_211",
+            "TENSORFLOW_PY39_210",
             "TENSORFLOW_PY38_26",
             "MXNET_PY39_19",
             "MXNET_PY38_18",
@@ -406,7 +463,6 @@ def notebook(
     "--custom-image",
     type=click.STRING,
     help="Docker Image to use for the job.  Implies 'CUSTOM' environment type.",
-    multiple=True,
 )
 @click.option(
     "--env",
@@ -417,11 +473,7 @@ def notebook(
 @click.option(
     "--key",
     type=click.Choice(
-        [
-            "aws",
-            "gcp",
-            "kaggle",
-        ],
+        ["aws", "gcp", "kaggle", "azure", "wasabi"],
         case_sensitive=False,
     ),
     help="Third Party Keys to add to the job environment",
@@ -475,9 +527,12 @@ def training(
     data_dir,
     dataset,
     public_dataset,
+    checkpoint,
+    public_checkpoint,
     output_dir,
     output_type,
     output_uri,
+    archive,
     environment,
     custom_image,
     env,
@@ -495,27 +550,45 @@ def training(
     Create a training job.
     """
 
-    datasets = [dict(id=item, type="existing") for item in dataset] + [
-        dict(id=item, type="public") for item in public_dataset
-    ]
+    datasets = [
+        dict(
+            id=item,
+        )
+        for item in dataset
+    ] + [dict(id=item, public=True) for item in public_dataset]
+
+    checkpoints = [
+        dict(
+            id=item,
+        )
+        for item in checkpoint
+    ] + [dict(id=item, public=True) for item in public_checkpoint]
 
     options = dict(
         max_price=max_price,
         data=dict(datasets=datasets),
+        model=dict(checkpoints=checkpoints),
         environment=dict(
-            type="CUSTOM" if custom_image else environment,
-            custom_image=custom_image,
             worker_key_types=[k for k in key],
         ),
     )
+    if custom_image:
+        options["environment"]["type"] = "CUSTOM"
+        options["environment"]["custom_image"] = custom_image
+    else:
+        options["environment"]["type"] = environment
 
     if output_type:
         options["data"]["output_type"] = output_type
         options["data"]["output_uri"] = output_uri
+        if not archive:
+            options["data"]["output_options"] = dict(archive=False)
 
     if output_dir:
         options["data"]["output_type"] = "local"
         options["data"]["output_uri"] = output_dir
+        if not archive:
+            options["data"]["output_options"] = dict(archive=False)
 
     try:
         envs = [
@@ -557,11 +630,15 @@ def training(
         )
 
     if git_uri:
-        options["model"] = dict(source_type="git", source_uri=git_uri)
+        options["model"]["source_type"] = "git"
+        options["model"]["source_uri"] = git_uri
     if model_id:
-        options["model"] = dict(source_type="trainml", source_uri=model_id)
+        options["model"]["source_type"] = "trainml"
+        options["model"]["source_uri"] = model_id
     if model_dir:
-        options["model"] = dict(source_type="local", source_uri=model_dir)
+        options["model"]["source_type"] = "local"
+        options["model"]["source_uri"] = model_dir
+
     job = config.trainml.run(
         config.trainml.client.jobs.create(
             name=name,
@@ -627,6 +704,7 @@ def training(
             "v100",
             "a100",
             "a6000",
+            "a4000",
             "cpu",
         ],
         case_sensitive=False,
@@ -643,6 +721,18 @@ def training(
     show_default=True,
     help="Max Price (per GPU).",
 )
+@click.option(
+    "--checkpoint",
+    type=click.STRING,
+    help="ID or Name of a checkpoint to add to the job",
+    multiple=True,
+)
+@click.option(
+    "--public-checkpoint",
+    type=click.STRING,
+    help="ID or Name of a public checkpoint to add to the job",
+    multiple=True,
+)
 @click.option(
     "--input-dir",
     type=click.Path(exists=True, file_okay=False, resolve_path=True),
@@ -651,7 +741,7 @@ def training(
 @click.option(
     "--input-type",
     type=click.Choice(
-        ["aws", "gcp", "local", "kaggle", "web"],
+        ["aws", "gcp", "local", "kaggle", "web", "azure", "wasabi"],
         case_sensitive=False,
     ),
     help="Service provider to load the input data",
@@ -669,7 +759,7 @@ def training(
 @click.option(
     "--output-type",
     type=click.Choice(
-        ["aws", "gcp", "local", "trainml"],
+        ["aws", "gcp", "local", "trainml", "azure", "wasabi"],
         case_sensitive=False,
     ),
     help="Service provider to store the output data",
@@ -679,18 +769,25 @@ def training(
     type=click.STRING,
     help="Location in the output-type provider to store the output data",
 )
+@click.option(
+    "--archive/--no-archive",
+    default=False,
+    show_default=True,
+    help="Zip the output contents before uploading.",
+)
 @click.option(
     "--environment",
     type=click.Choice(
         [
             "DEEPLEARNING_PY38",
             "DEEPLEARNING_PY39",
+            "PYTORCH_PY39_113",
             "PYTORCH_PY39_112",
             "PYTORCH_PY38_110",
             "PYTORCH_PY38_19",
             "PYTORCH_PY38_18",
-            "TENSORFLOW_PY39_29",
-            "TENSORFLOW_PY39_28",
+            "TENSORFLOW_PY39_211",
+            "TENSORFLOW_PY39_210",
             "TENSORFLOW_PY38_26",
             "MXNET_PY39_19",
             "MXNET_PY38_18",
@@ -705,7 +802,6 @@ def training(
     "--custom-image",
     type=click.STRING,
     help="Docker Image to use for the job.  Implies 'CUSTOM' environment type.",
-    multiple=True,
 )
 @click.option(
     "--env",
@@ -716,11 +812,7 @@ def training(
 @click.option(
     "--key",
     type=click.Choice(
-        [
-            "aws",
-            "gcp",
-            "kaggle",
-        ],
+        ["aws", "gcp", "kaggle", "azure", "wasabi"],
         case_sensitive=False,
     ),
     help="Third Party Keys to add to the job environment",
@@ -770,12 +862,15 @@ def inference(
     gpu_count,
     gpu_type,
     max_price,
+    checkpoint,
+    public_checkpoint,
     input_dir,
     input_type,
     input_uri,
     output_dir,
     output_type,
     output_uri,
+    archive,
     environment,
     custom_image,
     env,
@@ -793,15 +888,26 @@ def inference(
     Create an inference job.
     """
 
+    checkpoints = [
+        dict(
+            id=item,
+        )
+        for item in checkpoint
+    ] + [dict(id=item, public=True) for item in public_checkpoint]
+
     options = dict(
         max_price=max_price,
         data=dict(datasets=[]),
+        model=dict(checkpoints=checkpoints),
         environment=dict(
-            type="CUSTOM" if custom_image else environment,
-            custom_image=custom_image,
             worker_key_types=[k for k in key],
         ),
     )
+    if custom_image:
+        options["environment"]["type"] = "CUSTOM"
+        options["environment"]["custom_image"] = custom_image
+    else:
+        options["environment"]["type"] = environment
 
     if input_type:
         options["data"]["input_type"] = input_type
@@ -814,10 +920,14 @@ def inference(
     if output_type:
         options["data"]["output_type"] = output_type
         options["data"]["output_uri"] = output_uri
+        if not archive:
+            options["data"]["output_options"] = dict(archive=False)
 
     if output_dir:
         options["data"]["output_type"] = "local"
         options["data"]["output_uri"] = output_dir
+        if not archive:
+            options["data"]["output_options"] = dict(archive=False)
 
     try:
         envs = [
@@ -841,11 +951,15 @@ def inference(
             )
 
     if git_uri:
-        options["model"] = dict(source_type="git", source_uri=git_uri)
+        options["model"]["source_type"] = "git"
+        options["model"]["source_uri"] = git_uri
     if model_id:
-        options["model"] = dict(source_type="trainml", source_uri=model_id)
+        options["model"]["source_type"] = "trainml"
+        options["model"]["source_uri"] = model_id
     if model_dir:
-        options["model"] = dict(source_type="local", source_uri=model_dir)
+        options["model"]["source_type"] = "local"
+        options["model"]["source_uri"] = model_dir
+
     job = config.trainml.run(
         config.trainml.client.jobs.create(
             name=name,
@@ -947,6 +1061,7 @@ def from_json(config, attach, connect, file):
             "v100",
             "a100",
             "a6000",
+            "a4000",
             "cpu",
         ],
         case_sensitive=False,
@@ -963,18 +1078,31 @@ def from_json(config, attach, connect, file):
     show_default=True,
     help="Max Price (per GPU).",
 )
+@click.option(
+    "--checkpoint",
+    type=click.STRING,
+    help="ID or Name of a checkpoint to add to the job",
+    multiple=True,
+)
+@click.option(
+    "--public-checkpoint",
+    type=click.STRING,
+    help="ID or Name of a public checkpoint to add to the job",
+    multiple=True,
+)
 @click.option(
     "--environment",
     type=click.Choice(
         [
             "DEEPLEARNING_PY38",
             "DEEPLEARNING_PY39",
+            "PYTORCH_PY39_113",
             "PYTORCH_PY39_112",
             "PYTORCH_PY38_110",
             "PYTORCH_PY38_19",
             "PYTORCH_PY38_18",
-            "TENSORFLOW_PY39_29",
-            "TENSORFLOW_PY39_28",
+            "TENSORFLOW_PY39_211",
+            "TENSORFLOW_PY39_210",
             "TENSORFLOW_PY38_26",
             "MXNET_PY39_19",
             "MXNET_PY38_18",
@@ -989,7 +1117,6 @@ def from_json(config, attach, connect, file):
     "--custom-image",
     type=click.STRING,
     help="Docker Image to use for the job.  Implies 'CUSTOM' environment type.",
-    multiple=True,
 )
 @click.option(
     "--env",
@@ -1000,11 +1127,7 @@ def from_json(config, attach, connect, file):
 @click.option(
     "--key",
     type=click.Choice(
-        [
-            "aws",
-            "gcp",
-            "kaggle",
-        ],
+        ["aws", "gcp", "kaggle", "azure", "wasabi"],
         case_sensitive=False,
     ),
     help="Third Party Keys to add to the job environment",
@@ -1046,6 +1169,13 @@ def from_json(config, attach, connect, file):
     help="Routes to configure in endpoint (in JSON).",
     multiple=True,
 )
+@click.option(
+    "--timeout",
+    type=click.INT,
+    default=300,
+    show_default=True,
+    help="Seconds to wait for job to start",
+)
 @click.argument("name", type=click.STRING)
 @pass_config
 def endpoint(
@@ -1056,6 +1186,8 @@ def endpoint(
     gpu_count,
     gpu_type,
     max_price,
+    checkpoint,
+    public_checkpoint,
     environment,
     custom_image,
     env,
@@ -1067,21 +1199,33 @@ def endpoint(
     git_uri,
     model_id,
     route,
+    timeout,
     name,
 ):
     """
-    Create an inference job.
+    Create an endpoint.
     """
+    checkpoints = [
+        dict(
+            id=item,
+        )
+        for item in checkpoint
+    ] + [dict(id=item, public=True) for item in public_checkpoint]
+
     routes = [json.loads(item) for item in route]
 
     options = dict(
         max_price=max_price,
+        model=dict(checkpoints=checkpoints),
         environment=dict(
-            type="CUSTOM" if custom_image else environment,
-            custom_image=custom_image,
             worker_key_types=[k for k in key],
         ),
     )
+    if custom_image:
+        options["environment"]["type"] = "CUSTOM"
+        options["environment"]["custom_image"] = custom_image
+    else:
+        options["environment"]["type"] = environment
 
     try:
         envs = [
@@ -1105,11 +1249,15 @@ def endpoint(
             )
 
     if git_uri:
-        options["model"] = dict(source_type="git", source_uri=git_uri)
+        options["model"]["source_type"] = "git"
+        options["model"]["source_uri"] = git_uri
     if model_id:
-        options["model"] = dict(source_type="trainml", source_uri=model_id)
+        options["model"]["source_type"] = "trainml"
+        options["model"]["source_uri"] = model_id
     if model_dir:
-        options["model"] = dict(source_type="local", source_uri=model_dir)
+        options["model"]["source_type"] = "local"
+        options["model"]["source_uri"] = model_dir
+
     job = config.trainml.run(
         config.trainml.client.jobs.create(
             name=name,
@@ -1131,14 +1279,14 @@ def endpoint(
         else:
             config.trainml.run(job.connect())
         click.echo("Waiting for job to start...", file=config.stdout)
-        config.trainml.run(job.wait_for("running"))
+        config.trainml.run(job.wait_for("running", timeout))
         config.trainml.run(job.disconnect())
         config.trainml.run(job.refresh())
         click.echo(f"Endpoint is running at:  {job.url}", file=config.stdout)
     else:
         if connect:
             click.echo("Waiting for job to start...", file=config.stdout)
-            config.trainml.run(job.wait_for("running"))
+            config.trainml.run(job.wait_for("running", timeout))
             config.trainml.run(job.refresh())
             click.echo(
                 f"Endpoint is running at:  {job.url}", file=config.stdout
