@@ -9,6 +9,7 @@ from importlib.metadata import version
 from trainml.auth import Auth
 from trainml.datasets import Datasets
 from trainml.models import Models
+from trainml.checkpoints import Checkpoints
 from trainml.jobs import Jobs
 from trainml.gpu_types import GpuTypes
 from trainml.environments import Environments
@@ -62,6 +63,7 @@ class TrainML(object):
         )
         self.datasets = Datasets(self)
         self.models = Models(self)
+        self.checkpoints = Checkpoints(self)
         self.jobs = Jobs(self)
         self.gpu_types = GpuTypes(self)
         self.environments = Environments(self)
@@ -88,10 +90,11 @@ class TrainML(object):
     async def _query(self, path, method, params=None, data=None, headers=None):
         try:
             tokens = self.auth.get_tokens()
+        except TrainMLException as e:
+            raise e
         except Exception:
-            logging.debug(traceback.format_exc())
             raise TrainMLException(
-                "Error getting authorization tokens.  Verify configured credentials."
+                f"Error getting authorization tokens.  Verify configured credentials. Error: {traceback.format_exc()}"
             )
         headers = (
             {
@@ -158,7 +161,14 @@ class TrainML(object):
             "User-Agent": f"trainML-sdk/{self._version}",
             "Content-Type": "application/json",
         }
-        tokens = self.auth.get_tokens()
+        try:
+            tokens = self.auth.get_tokens()
+        except TrainMLException as e:
+            raise e
+        except Exception:
+            raise TrainMLException(
+                f"Error getting authorization tokens.  Verify configured credentials. Error: {traceback.format_exc()}"
+            )
         async with aiohttp.ClientSession() as session:
             done = False
             async with session.ws_connect(
